=========
changelog
=========

ver 0.0.1
=========

First release.

Features
--------

* Watch source directory
* When reST file are changed in source dir, Run sphinx-build
* Run HTTP server with option
